@@ -43,7 +43,7 @@ package Astro::Coord::ECI::Moon;
 use strict;
 use warnings;
 
-our $VERSION = '0.040_01';
+our $VERSION = '0.042_01';
 
 use base qw{Astro::Coord::ECI};
 
@@ -60,10 +60,10 @@ my %terms;
 my $where;
 while (<DATA>) {
     chomp;
-    s/^\s+//;
-    s/\s+$//;
+    s/ \A \s+ //smx;
+    s/ \s+ \z //smx;
     next unless $_;
-    next if m/^#/;
+    next if m/ \A \s* [#] /smx;
     s/^-// and do {
 	last if $_ eq 'end';
 	$where = $terms{$_} ||= [];
@@ -228,6 +228,19 @@ sub almanac_hash {
     }, almanac(@_);
 }
 
+=item $tle->correct_for_refraction( $elevation )
+
+This override of the superclass' method simply returns the elevation
+passed to it. Since the Moon has no atmosphere to speak of, there should
+be no diffraction to speak of either.
+
+=cut
+
+sub correct_for_refraction {
+    my ( $self, $elevation ) = @_;
+    return $elevation;
+}
+
 
 =item ($time, $quarter, $desc) = $moon->next_quarter ($want);
 
@@ -490,7 +503,7 @@ eod
 
 #	Coordinates of Moon (finally!)
 
-    my $lambda = mod2pi( deg2rad ($sigmal / 1_000_000) + $Lprime );
+    my $lambda = deg2rad ($sigmal / 1_000_000) + $Lprime;
     my $beta = deg2rad ($sigmab / 1_000_000);
     my $delta = $sigmar / 1000 + 385_000.56;
 
@@ -498,7 +511,7 @@ eod
 
     $lambda += nutation_in_longitude ($time);
 
-    $self->ecliptic ($beta, $lambda, $delta);
+    $self->ecliptic ($beta, mod2pi( $lambda ), $delta);
     ## $self->set (equinox_dynamical => $time);
     $self->equinox_dynamical ($time);
     return $self;
@@ -670,3 +683,5 @@ __DATA__
 1  0 -1 -1	     -119
 4 -1  0 -1	      115
 2 -2  0  1	      107
+
+# ex: set textwidth=72 :
